@@ -3,7 +3,7 @@ from datetime import date
 from contextlib import contextmanager
 from collections import namedtuple
 from pathlib import Path
-from typing import IO, List, Dict, Union, Tuple, Any, Iterable, Sequence
+from typing import IO, List, Dict, Union, Tuple, Any, Iterable, Sequence, Mapping
 
 import yaml
 from yaml.composer import Composer
@@ -30,7 +30,9 @@ LineTracker = namedtuple("LineTracker", ["filename", "line_num"])
 
 
 class ParseResult:
-    def __init__(self, options, tables, templates, plugins: Sequence[str] = ()):
+    def __init__(
+        self, options, tables: Mapping, templates, plugins: Sequence[str] = ()
+    ):
         self.options = options
         self.tables = tables
         self.templates = templates
@@ -104,7 +106,7 @@ class ParseContext:
         finally:
             self.current_parent_object = _old_parsed_template
 
-    def register_object(self, template: ObjectTemplate) -> None:
+    def register_template(self, template: ObjectTemplate) -> None:
         """Register templates for later use.
 
         We register templates so we can get a list of all fields that can
@@ -291,7 +293,7 @@ def parse_object_template(yaml_sobj: Dict, context: ParseContext) -> ObjectTempl
         if count_expr is not None:
             parse_count_expression(yaml_sobj, sobj_def, context)
         new_template = ObjectTemplate(**sobj_def)
-        context.register_object(new_template)
+        context.register_template(new_template)
         return new_template
 
 
